@@ -40,7 +40,7 @@
 
 namespace KSysGuard
 {
-  class Processes::Private
+  class Q_DECL_HIDDEN Processes::Private
   {
     public:
       Private(Processes *q_ptr) {
@@ -519,7 +519,7 @@ bool Processes::loadHistoryFile(const QString &filename)
 QString Processes::historyFileName() const
 {
     if(!d->mIsLocalHost || !d->mHistoricProcesses)
-        return {};
+        return QString();
     return d->mHistoricProcesses->historyFileName();
 }
 QDateTime Processes::viewingTime() const
